@@ -11,7 +11,8 @@ __all__ = ['thread',
            'TaskCancelled']
 
 from .pebble import PebbleError, TaskCancelled, TimeoutError, Task
-from .process import ProcessPool
-from .thread import ThreadPool
-from .decorators import synchronized, thread, thread_pool
-from .decorators import process, process_pool
+from .pools.process import ProcessPool
+from .pools.thread import ThreadPool
+from .decorators.generic import synchronized
+from .decorators.thread import thread, thread_pool
+from .decorators.process import process, process_pool
