@@ -193,6 +193,36 @@ def pjob_pool_init_error(argument, keyword_argument=0):
     return argument + keyword_argument + initarg
 
 
+class ThreadClass(object):
+    class_value = 1
+
+    def __init__(self):
+        self.value = 1
+
+    @thread
+    def tjob(self, argument, keyword_argument=1):
+        return self.value + argument + keyword_argument
+
+    @thread_pool
+    def tjob_pool(self, argument, keyword_argument=1):
+        return self.value + argument + keyword_argument
+
+
+class ProcessClass(object):
+    class_value = 1
+
+    def __init__(self):
+        self.value = 1
+
+    @process
+    def pjob(self, argument, keyword_argument=1):
+        return self.value + argument + keyword_argument
+
+    @process_pool
+    def pjob_pool(self, argument, keyword_argument=1):
+        return self.value + argument + keyword_argument
+
+
 class UnserializeableError(Exception):
     def __init__(self):
         self.lock = threading.Lock()  # unpickleable
@@ -226,6 +256,7 @@ class TestThreadDecorators(unittest.TestCase):
         event.clear()
         self.exception = None
         self.callbackresults = 0
+        self.threadclass = ThreadClass()
 
     def callback(self, task):
         self.callbackresults = task.get()
@@ -247,6 +278,11 @@ class TestThreadDecorators(unittest.TestCase):
         except Exception as error:
             self.assertTrue(isinstance(error, ValueError))
 
+    def test_class_decorated_method(self):
+        """ThreadDecorator decorated method."""
+        task = self.threadclass.tjob(1)
+        self.assertEqual(task.get(), 3)
+
     def test_thread_callback_static(self):
         """ThreadDecorator static callback is executed with thread task."""
         tjob_callback(1, 1)
@@ -291,6 +327,7 @@ class TestThreadPoolDecorator(unittest.TestCase):
         event.clear()
         self.exception = None
         self.callback_results = 0
+        self.threadclass = ThreadClass()
 
     def callback(self, task):
         self.callback_results = task.get()
@@ -303,6 +340,11 @@ class TestThreadPoolDecorator(unittest.TestCase):
             self.exception = error
         event.set()
 
+    def test_class_pool_decorated_method(self):
+        """ThreadPoolDecorator decorated method."""
+        task = self.threadclass.tjob_pool(1)
+        self.assertEqual(task.get(), 3)
+
     def test_thread_pool_single_task(self):
         """ThreadPoolDecorator Single task with no parameters."""
         task = tjob_pool_single(1, 1)
@@ -376,7 +418,7 @@ class TestThreadPoolDecorator(unittest.TestCase):
         self.assertRaises(Exception, task.get)
 
     def test_thread_pool_cancel(self):
-        """ThreadPool callback gets notification if Task is cancelled."""
+        """ThreadPoolDecorator callback gets notification if Task is cancelled."""
         tjob_pool_long.callback = self.error_callback
         task = tjob_pool_long(1, 1)
         task.cancel()
@@ -384,7 +426,7 @@ class TestThreadPoolDecorator(unittest.TestCase):
         self.assertTrue(isinstance(self.exception, TaskCancelled))
 
     def test_thread_pool_callback_error(self):
-        """ThreadPool error within callback is safely handled."""
+        """ThreadPoolDecorator error within callback is safely handled."""
         tjob_pool_long.callback = self.error_callback
         task = tjob_pool_long(1, 1)
         task.cancel()
@@ -401,6 +443,7 @@ class TestProcessDecorator(unittest.TestCase):
         event.clear()
         self.exception = None
         self.callback_results = 0
+        self.processclass = ProcessClass()
 
     def callback(self, task):
         self.callback_results = task.get()
@@ -422,6 +465,11 @@ class TestProcessDecorator(unittest.TestCase):
         except Exception as error:
             self.assertTrue(isinstance(error, ValueError))
 
+    def test_class_decorated_method(self):
+        """ProcessDecorator decorated method."""
+        task = self.processclass.pjob(1)
+        self.assertEqual(task.get(), 3)
+
     def test_process_callback_static(self):
         """ProcessDecorator static callback is executed once task is done."""
         pjob_callback(1, 1)
@@ -508,6 +556,7 @@ class TestProcessPoolDecorator(unittest.TestCase):
         event.clear()
         self.exception = None
         self.callback_results = 0
+        self.processclass = ProcessClass()
 
     def callback(self, task):
         self.callback_results = task.get()
@@ -520,6 +569,11 @@ class TestProcessPoolDecorator(unittest.TestCase):
             self.exception = error
         event.set()
 
+    def test_class_decorated_method(self):
+        """ProcessPoolDecorator decorated method."""
+        task = self.processclass.pjob_pool(1)
+        self.assertEqual(task.get(), 3)
+
     def test_process_pool_single_task(self):
         """ProcessPoolDecorator Single task with no parameters."""
         task = pjob_pool_single(1, 1)
